@@ -1,6 +1,6 @@
 package Redis::Client;
 {
-  $Redis::Client::VERSION = '0.009';
+  $Redis::Client::VERSION = '0.010';
 }
 
 use Moose;
@@ -206,7 +206,7 @@ Redis::Client - Perl client for Redis 2.4 and up
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -286,11 +286,11 @@ if a connection cannot be obtained.
 
 =over
 
-=item C<host>
+=item * C<host>
 
 The hostname of the Redis server. Defaults to C<localhost>.
 
-=item C<port>
+=item * C<port>
 
 The port number of the Redis server. Defaults to C<6379>.
 
@@ -370,6 +370,16 @@ fatal error is thrown.
 
     my $val = $client->get( 'my_key' );
 
+=head2 getbit
+
+Redis L<GETBIT|http://redis.io/commands/getbit> command.
+
+Returns the value of one bit in a string. Takes the key name and the offset of
+the bit. If the offset is beyond the length of the string, C<0> is returned.
+If the key is not a string, a fatal error is thrown.
+
+    my $bit = $client->getbit( 'my_key', 4 );    # fifth bit from left
+
 =head2 getrange
 
 Redis L<GETRANGE|http://redis.io/commands/getrange> command.
@@ -527,6 +537,19 @@ to expire. A timeout of zero waits forever.
 
 See L<rpop> for the non-blocking version.
 
+=head2 brpoplpush
+
+Redis L<BRPOPLPUSH|http://redis.io/commands/brpoplpush> command.
+
+Blocking atomic right list pop with left list push. Takes the source to pop, the 
+destination list to push, and a timeout value. Returns the element being popped
+from the source and pushed to the destination, or C<undef> if it times out. A 
+timeout of zero waits forever.
+
+    my $val = $client->brpoplpush( 'source_list', 'dest_list', 5 ); 
+
+See L<rpoplpush> for the non-blocking version.
+
 =head2 lindex
 
 Redis L<LINDEX|http://redis.io/commands/lindex> command.
@@ -799,14 +822,6 @@ Returns whatever you send it. Useful for testing only. Takes one argument.
 
 =encoding utf8
 
-=str_methdod getbit
-
-Returns the value of one bit in a string. Takes the key name and the offset of
-the bit. If the offset is beyond the length of the string, C<0> is returned.
-If the key is not a string, a fatal error is thrown.
-
-    my $bit = $client->getbit( 'my_key', 4 );    # fifth bit from left
-
 =head1 CAVEATS
 
 This early release is not feature-complete. I've implemented all the Redis
